==> erpbrasil.edoc-2.7.0-py2.py3-none-any.whl: erpbrasil/edoc/resposta.py <==
# -*- coding: utf-8 -*-
# Copyright (C) 2018 - TODAY Luis Felipe Mileo - KMEE INFORMATICA LTDA
# License MIT

import re

from lxml import etree


class RetornoSoap(object):

    def __init__(self, webservice, raiz, xml, retorno, resposta):
        self.webservice = webservice
        self.envio_raiz = raiz
        self.envio_xml = xml
        self.resposta = resposta
        self.retorno = retorno


def analisar_retorno_raw(operacao, raiz, xml, retorno, classe):
    retorno.raise_for_status()
    match = re.search('<soap:Body>(.*?)</soap:Body>',
                      retorno.text.replace('\n', ''))
    if match:
        xml_resposta = match.group(1)
        xml_etree = etree.fromstring(xml_resposta)
        resultado = xml_etree[0]

        nome_classe = classe.__name__.split(".")[-1]
        xml_classe_tags = list(filter(
            lambda children: nome_classe in children.tag,
            xml_etree.findall(".//")
        ))
        if xml_classe_tags:
            resultado = xml_classe_tags[0]

        resultado = etree.tostring(resultado)
        classe.Validate_simpletypes_ = False
        resposta = classe.parseString(resultado, silence=True)
        return RetornoSoap(operacao, raiz, xml, retorno, resposta)


def analisar_retorno(operacao, raiz, xml, retorno, classe):
    resposta = False
    if retorno:
        classe.Validate_simpletypes_ = False
        resultado = etree.tostring(
            etree.fromstring(retorno.encode('utf-8')))
        resposta = classe.parseString(resultado, silence=True)
    return RetornoSoap(operacao, raiz, xml, retorno, resposta)

==> erpbrasil.edoc-2.9.0-py2.py3-none-any.whl: erpbrasil/edoc/resposta.py <==
# Copyright (C) 2018 - TODAY Luis Felipe Mileo - KMEE INFORMATICA LTDA
# License MIT

import re

from lxml import etree


class RetornoSoap:
    def __init__(self, webservice, raiz, xml, retorno, resposta):
        self.webservice = webservice
        self.envio_raiz = raiz
        self.envio_xml = xml
        self.resposta = resposta
        self.retorno = retorno


def analisar_retorno_raw(operacao, raiz, xml, retorno, classe):
    retorno.raise_for_status()
    match = re.search("<soap:Body>(.*?)</soap:Body>", retorno.text.replace("\n", ""))
    if match:
        xml_resposta = match.group(1)
        xml_etree = etree.fromstring(xml_resposta)
        resultado = xml_etree[0]

        nome_classe = classe.__name__.split(".")[-1]
        xml_classe_tags = list(
            filter(
                lambda children: nome_classe in children.tag, xml_etree.findall(".//")
            )
        )
        if xml_classe_tags:
            resultado = xml_classe_tags[0]

        resultado = etree.tostring(resultado)
        classe.Validate_simpletypes_ = False
        resposta = classe.parseString(resultado, silence=True)
        return RetornoSoap(operacao, raiz, xml, retorno, resposta)


def analisar_retorno(operacao, raiz, xml, retorno, classe):
    resposta = False
    if retorno:
        classe.Validate_simpletypes_ = False
        resultado = etree.tostring(etree.fromstring(retorno.encode("utf-8")))
        resposta = classe.parseString(resultado, silence=True)
    return RetornoSoap(operacao, raiz, xml, retorno, resposta)
